@@ -21,7 +21,7 @@ package org.apache.flink.connector.jdbc.table;
 import org.apache.flink.connector.jdbc.JdbcDataTestBase;
 import org.apache.flink.connector.jdbc.JdbcExecutionOptions;
 import org.apache.flink.connector.jdbc.internal.JdbcOutputFormat;
-import org.apache.flink.connector.jdbc.internal.options.JdbcConnectorOptions;
+import org.apache.flink.connector.jdbc.internal.options.InternalJdbcConnectionOptions;
 import org.apache.flink.connector.jdbc.internal.options.JdbcDmlOptions;
 import org.apache.flink.table.api.DataTypes;
 import org.apache.flink.table.data.RowData;
@@ -42,7 +42,6 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.util.Arrays;
 
-import static org.apache.flink.connector.jdbc.JdbcTestFixture.DERBY_EBOOKSHOP_DB;
 import static org.apache.flink.connector.jdbc.JdbcTestFixture.INPUT_TABLE;
 import static org.apache.flink.connector.jdbc.JdbcTestFixture.OUTPUT_TABLE;
 import static org.apache.flink.connector.jdbc.JdbcTestFixture.OUTPUT_TABLE_2;
@@ -89,10 +88,10 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
         String expectedMsg = "unable to open JDBC writer";
         assertThatThrownBy(
                         () -> {
-                            JdbcConnectorOptions jdbcOptions =
-                                    JdbcConnectorOptions.builder()
+                            InternalJdbcConnectionOptions jdbcOptions =
+                                    InternalJdbcConnectionOptions.builder()
                                             .setDriverName("org.apache.derby.jdbc.idontexist")
-                                            .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                                            .setDBUrl(getMetadata().getJdbcUrl())
                                             .setTableName(INPUT_TABLE)
                                             .build();
                             JdbcDmlOptions dmlOptions =
@@ -120,9 +119,9 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
     void testInvalidURL() {
         assertThatThrownBy(
                         () -> {
-                            JdbcConnectorOptions jdbcOptions =
-                                    JdbcConnectorOptions.builder()
-                                            .setDriverName(DERBY_EBOOKSHOP_DB.getDriverClass())
+                            InternalJdbcConnectionOptions jdbcOptions =
+                                    InternalJdbcConnectionOptions.builder()
+                                            .setDriverName(getMetadata().getDriverClass())
                                             .setDBUrl("jdbc:der:iamanerror:mory:ebookshop")
                                             .setTableName(INPUT_TABLE)
                                             .build();
@@ -150,10 +149,10 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
     void testIncompatibleTypes() {
         assertThatThrownBy(
                         () -> {
-                            JdbcConnectorOptions jdbcOptions =
-                                    JdbcConnectorOptions.builder()
-                                            .setDriverName(DERBY_EBOOKSHOP_DB.getDriverClass())
-                                            .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                            InternalJdbcConnectionOptions jdbcOptions =
+                                    InternalJdbcConnectionOptions.builder()
+                                            .setDriverName(getMetadata().getDriverClass())
+                                            .setDBUrl(getMetadata().getJdbcUrl())
                                             .setTableName(INPUT_TABLE)
                                             .build();
                             JdbcDmlOptions dmlOptions =
@@ -189,10 +188,10 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
     void testExceptionOnInvalidType() {
         assertThatThrownBy(
                         () -> {
-                            JdbcConnectorOptions jdbcOptions =
-                                    JdbcConnectorOptions.builder()
-                                            .setDriverName(DERBY_EBOOKSHOP_DB.getDriverClass())
-                                            .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                            InternalJdbcConnectionOptions jdbcOptions =
+                                    InternalJdbcConnectionOptions.builder()
+                                            .setDriverName(getMetadata().getDriverClass())
+                                            .setDBUrl(getMetadata().getJdbcUrl())
                                             .setTableName(OUTPUT_TABLE)
                                             .build();
                             JdbcDmlOptions dmlOptions =
@@ -230,10 +229,10 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
         String expectedMsg = "Writing records to JDBC failed.";
         assertThatThrownBy(
                         () -> {
-                            JdbcConnectorOptions jdbcOptions =
-                                    JdbcConnectorOptions.builder()
-                                            .setDriverName(DERBY_EBOOKSHOP_DB.getDriverClass())
-                                            .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+                            InternalJdbcConnectionOptions jdbcOptions =
+                                    InternalJdbcConnectionOptions.builder()
+                                            .setDriverName(getMetadata().getDriverClass())
+                                            .setDBUrl(getMetadata().getJdbcUrl())
                                             .setTableName(OUTPUT_TABLE)
                                             .build();
                             JdbcDmlOptions dmlOptions =
@@ -276,10 +275,10 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
 
     @Test
     void testJdbcOutputFormat() throws IOException, SQLException {
-        JdbcConnectorOptions jdbcOptions =
-                JdbcConnectorOptions.builder()
-                        .setDriverName(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+        InternalJdbcConnectionOptions jdbcOptions =
+                InternalJdbcConnectionOptions.builder()
+                        .setDriverName(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setTableName(OUTPUT_TABLE)
                         .build();
         JdbcDmlOptions dmlOptions =
@@ -310,7 +309,7 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
 
         outputFormat.close();
 
-        try (Connection dbConn = DriverManager.getConnection(DERBY_EBOOKSHOP_DB.getJdbcUrl());
+        try (Connection dbConn = DriverManager.getConnection(getMetadata().getJdbcUrl());
                 PreparedStatement statement = dbConn.prepareStatement(SELECT_ALL_NEWBOOKS);
                 ResultSet resultSet = statement.executeQuery()) {
             int recordCount = 0;
@@ -329,10 +328,10 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
 
     @Test
     void testFlush() throws SQLException, IOException {
-        JdbcConnectorOptions jdbcOptions =
-                JdbcConnectorOptions.builder()
-                        .setDriverName(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+        InternalJdbcConnectionOptions jdbcOptions =
+                InternalJdbcConnectionOptions.builder()
+                        .setDriverName(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setTableName(OUTPUT_TABLE_2)
                         .build();
         JdbcDmlOptions dmlOptions =
@@ -355,7 +354,7 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
         setRuntimeContext(outputFormat, true);
         outputFormat.open(0, 1);
 
-        try (Connection dbConn = DriverManager.getConnection(DERBY_EBOOKSHOP_DB.getJdbcUrl());
+        try (Connection dbConn = DriverManager.getConnection(getMetadata().getJdbcUrl());
                 PreparedStatement statement = dbConn.prepareStatement(SELECT_ALL_NEWBOOKS_2)) {
             outputFormat.open(0, 1);
             for (int i = 0; i < 2; ++i) {
@@ -399,10 +398,10 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
 
     @Test
     void testFlushWithBatchSizeEqualsZero() throws SQLException, IOException {
-        JdbcConnectorOptions jdbcOptions =
-                JdbcConnectorOptions.builder()
-                        .setDriverName(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+        InternalJdbcConnectionOptions jdbcOptions =
+                InternalJdbcConnectionOptions.builder()
+                        .setDriverName(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setTableName(OUTPUT_TABLE_2)
                         .build();
         JdbcDmlOptions dmlOptions =
@@ -424,7 +423,7 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
                         .build();
         setRuntimeContext(outputFormat, true);
 
-        try (Connection dbConn = DriverManager.getConnection(DERBY_EBOOKSHOP_DB.getJdbcUrl());
+        try (Connection dbConn = DriverManager.getConnection(getMetadata().getJdbcUrl());
                 PreparedStatement statement = dbConn.prepareStatement(SELECT_ALL_NEWBOOKS_2)) {
             outputFormat.open(0, 1);
             for (int i = 0; i < 2; ++i) {
@@ -446,10 +445,10 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
 
     @Test
     void testInvalidConnectionInJdbcOutputFormat() throws IOException, SQLException {
-        JdbcConnectorOptions jdbcOptions =
-                JdbcConnectorOptions.builder()
-                        .setDriverName(DERBY_EBOOKSHOP_DB.getDriverClass())
-                        .setDBUrl(DERBY_EBOOKSHOP_DB.getJdbcUrl())
+        InternalJdbcConnectionOptions jdbcOptions =
+                InternalJdbcConnectionOptions.builder()
+                        .setDriverName(getMetadata().getDriverClass())
+                        .setDBUrl(getMetadata().getJdbcUrl())
                         .setTableName(OUTPUT_TABLE_3)
                         .build();
         JdbcDmlOptions dmlOptions =
@@ -489,7 +488,7 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
 
         outputFormat.close();
 
-        try (Connection dbConn = DriverManager.getConnection(DERBY_EBOOKSHOP_DB.getJdbcUrl());
+        try (Connection dbConn = DriverManager.getConnection(getMetadata().getJdbcUrl());
                 PreparedStatement statement = dbConn.prepareStatement(SELECT_ALL_NEWBOOKS_3);
                 ResultSet resultSet = statement.executeQuery()) {
             int recordCount = 0;
@@ -508,7 +507,7 @@ class JdbcOutputFormatTest extends JdbcDataTestBase {
 
     @AfterEach
     void clearOutputTable() throws Exception {
-        try (Connection conn = DERBY_EBOOKSHOP_DB.getConnection();
+        try (Connection conn = getMetadata().getConnection();
                 Statement stat = conn.createStatement()) {
             stat.execute("DELETE FROM " + OUTPUT_TABLE);
         }
